th_get: Get a dataset from the Open Government Data of Thailand API.

View source: R/functions.R

th_getR Documentation

Get a dataset from the Open Government Data of Thailand API.

Description

Get a dataset from the Open Government Data of Thailand API.

Usage

th_get(resource_id, limit = 999999999999, ...)

Arguments

resource_id

Resource ID of the dataset to download.

limit

by default this is set to 999,999,999,999 rows.

Examples

th_get("245c98c3-2f92-4d58-a892-3fabf2af0772")

asiripanich/thaigov documentation built on April 25, 2022, 12:35 p.m.