th_package_list: Return a list of the names of the site’s datasets (packages).

View source: R/functions.R

th_package_listR Documentation

Return a list of the names of the site’s datasets (packages).

Description

Return a list of the names of the site’s datasets (packages).

Usage

th_package_list()

Value

a character vector.

Examples

th_package_list()

asiripanich/thaigov documentation built on April 25, 2022, 12:35 p.m.